## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")
library(gp3ml)

## -----------------------------------------------------------------------------
profile <- create_gp3ml_governance_profile(
  evidence = list(
    task = structure(list(), class = "gp3ml_task"),
    feature_manifest = structure(list(), class = "gazepoint_feature_manifest")
  ),
  framework = "NIST-AI-RMF-1.0"
)

audit <- audit_gp3ml_governance_profile(profile)
audit$status
plot(audit)

