## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")
options(gp3ml.reproducible_examples = TRUE)
library(gp3ml)

## ----normalize----------------------------------------------------------------
volatile <- c(
  paste0(
    "Generated",
    ": 2026-07-25 23:26:03 UTC"
  ),
  paste0(
    "<environment: 0x",
    "000001234ABCDEF0>"
  )
)

normalize_gazepoint_artifact_text(volatile)

## ----audit--------------------------------------------------------------------
example_file <- tempfile(fileext = ".md")
writeLines(
  paste0(
    "Generated",
    ": 2026-07-25 23:26:03 UTC"
  ),
  example_file
)
audit <- audit_gazepoint_reproducibility(example_file)
audit
plot(audit)
unlink(example_file)

