## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")
library(gp3ml)

## -----------------------------------------------------------------------------
reference <- capture_gazepoint_environment(packages = "gp3ml")
comparison <- compare_gazepoint_environments(reference, reference)
comparison$status
plot(comparison)

