## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")
options(gp3ml.reproducible_examples = TRUE)
library(gp3ml)

## ----capabilities-------------------------------------------------------------
capabilities <- gp3ml_engine_capabilities(
  check_keras_backend = FALSE
)
capabilities
plot(capabilities)

## ----base-assertions----------------------------------------------------------
assert_gp3ml_engine_available("glm")
assert_gp3ml_engine_available("lm")

