% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/feature-provenance-manifest.R
\name{print.gazepoint_feature_manifest_validation}
\alias{print.gazepoint_feature_manifest_validation}
\title{Print feature-manifest validation}
\usage{
\method{print}{gazepoint_feature_manifest_validation}(x, ...)
}
\arguments{
\item{x}{An object returned by
\code{\link[=validate_gazepoint_feature_manifest]{validate_gazepoint_feature_manifest()}}.}

\item{...}{Additional arguments, currently unused.}
}
\value{
\code{x}, invisibly.
}
\description{
Print feature-manifest validation
}
\examples{
manifest <- create_gazepoint_feature_manifest(
  features = "fixation_duration",
  scientific_source = "Gazepoint fixation export",
  source_table = "fixations",
  transformation = "Trial-level mean",
  availability_stage = "during_exposure",
  prediction_time_available = TRUE,
  preprocessing_scope = "none",
  fold_local_required = FALSE
)
validation <- validate_gazepoint_feature_manifest(manifest)
print(validation)
}
